@@ -1,11 +1,12 @@
-from bigquery_frame import DataFrame, BigQueryBuilder
-from bigquery_frame.auth import get_bq_client
+from bigquery_frame import DataFrame
 
 
 def sort_columns(df: DataFrame) -> DataFrame:
     """Returns a new DataFrame where the order of columns has been sorted
 
     Examples:
+    >>> from bigquery_frame import BigQueryBuilder
+    >>> from bigquery_frame.auth import get_bq_client
     >>> bq = BigQueryBuilder(get_bq_client())
     >>> df = bq.sql('''SELECT 1 as b, 1 as a, 1 as c''')
     >>> df.printSchema()
@@ -22,4 +23,3 @@ def sort_columns(df: DataFrame) -> DataFrame:
     <BLANKLINE>
     """
     return df.select(*sorted(df.columns))
-
